
<!--
FrozenIsBool False
-->

#Pointer

##Doc
----


> 
> A Pointer 
> 
> 

----

<small>
View the Pointer notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Pointer.ipynb)
</small>

